@@ -295,8 +295,8 @@ class Update:
         user = {
             "active": not person["terminated"],
             "name": {
-                "familyName": person["last_name"],
-                "givenName": person["first_name"],
+                "familyName": person["last_name_ascii"],
+                "givenName": person["first_name_ascii"],
                 "honorificPrefix": None,
             },
             "phoneNumbers": [
@@ -444,6 +444,9 @@ class Update:
                 if new != old:
                     updates.append(f"  {key}: {old} -> {new}")
                     user[key] = new
+                    if key == 'phoneNumbers' and not user[key][1]["value"]:
+                        user[key][1]["value"] = " "
+
             if updates:
                 print(f"\nUpdating user: {email}...")
                 print("\n".join(updates))
